==> kdeutils-4.1.1.tar.bz2: kdeutils-4.1.1/okteta/program/libkakao/controllers/io/export/exportcontroller.h <==
/*
    This file is part of the Kakao Framework, part of the KDE project.

    Copyright 2008 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef EXPORTCONTROLLER_H
#define EXPORTCONTROLLER_H


// kakao
#include <kviewcontroller.h>

class QAction;
class QActionGroup;
class KXmlGuiWindow;
class KDocumentManager;
namespace KDE { namespace If {
class DataSelectable;
} }


class ExportController : public KViewController
{
  Q_OBJECT

  public:
    ExportController( KDocumentManager *documentManager, KXmlGuiWindow *window );

  public: // KViewController API
    virtual void setView( KAbstractView *view );

  private Q_SLOTS:
    void updateActions();
    void onActionTriggered( QAction *action );

  protected:
    KDocumentManager *mDocumentManager;
    KXmlGuiWindow *mWindow;

    KAbstractView *mView;
    KDE::If::DataSelectable *mSelectionControl;

    QActionGroup *mExportActionGroup;
};

#endif

==> kdeutils-4.2.4.tar.bz2: kdeutils-4.2.4/okteta/program/libkakao/controllers/io/export/exportcontroller.h <==
/*
    This file is part of the Kakao Framework, part of the KDE project.

    Copyright 2008 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef EXPORTCONTROLLER_H
#define EXPORTCONTROLLER_H


// kakao
#include <abstractxmlguicontroller.h>

class KViewManager;
class KDocumentManager;
namespace KDE { namespace If {
class DataSelectable;
} }
class KXMLGUIClient;
class KSelectAction;
class QAction;


class ExportController : public AbstractXmlGuiController
{
  Q_OBJECT

  public:
    ExportController( KViewManager* viewManager, KDocumentManager* documentManager, KXMLGUIClient* guiClient );

  public: // AbstractXmlGuiController API
    virtual void setTargetModel( AbstractModel* model );

  private Q_SLOTS:
    void updateActions();
    void onActionTriggered( QAction *action );

  protected:
    KViewManager* mViewManager;
    KDocumentManager *mDocumentManager;
    KXMLGUIClient *mGuiClient;

    AbstractModel* mModel;
    KDE::If::DataSelectable *mSelectionControl;

    KSelectAction* mExportSelectAction;
};

#endif
